<?php

namespace Litecms\UnilevelSetting\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\UnilevelSetting\Http\Requests\UnilevelSettingRequest;
use Litecms\UnilevelSetting\Interfaces\UnilevelSettingRepositoryInterface;
use Litecms\UnilevelSetting\Models\UnilevelSetting;

/**
 * Resource controller class for unilevel_setting.
 */
class UnilevelSettingResourceController extends BaseController
{

    /**
     * Initialize unilevel_setting resource controller.
     *
     * @param type UnilevelSettingRepositoryInterface $unilevel_setting
     *
     * @return null
     */
    public function __construct(UnilevelSettingRepositoryInterface $unilevel_setting)
    {
        parent::__construct();
        $this->repository = $unilevel_setting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\UnilevelSetting\Repositories\Criteria\UnilevelSettingResourceCriteria::class);
    }

    /**
     * Display a list of unilevel_setting.
     *
     * @return Response
     */
    public function index(UnilevelSettingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\UnilevelSetting\Repositories\Presenter\UnilevelSettingPresenter::class)
                ->$function();
        }

        $unilevel_settings = $this->repository->paginate();

        return $this->response->title(trans('unilevel_setting::unilevel_setting.names'))
            ->view('unilevel_setting::unilevel_setting.index', true)
            ->data(compact('unilevel_settings'))
            ->output();
    }

    /**
     * Display unilevel_setting.
     *
     * @param Request $request
     * @param Model   $unilevel_setting
     *
     * @return Response
     */
    public function show(UnilevelSettingRequest $request, UnilevelSetting $unilevel_setting)
    {

        if ($unilevel_setting->exists) {
            $view = 'unilevel_setting::unilevel_setting.show';
        } else {
            $view = 'unilevel_setting::unilevel_setting.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('unilevel_setting::unilevel_setting.name'))
            ->data(compact('unilevel_setting'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new unilevel_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(UnilevelSettingRequest $request)
    {

        $unilevel_setting = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('unilevel_setting::unilevel_setting.name')) 
            ->view('unilevel_setting::unilevel_setting.create', true) 
            ->data(compact('unilevel_setting'))
            ->output();
    }

    /**
     * Create new unilevel_setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(UnilevelSettingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $unilevel_setting                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('unilevel_setting::unilevel_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('unilevel_setting/unilevel_setting/' . $unilevel_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/unilevel_setting/unilevel_setting'))
                ->redirect();
        }

    }

    /**
     * Show unilevel_setting for editing.
     *
     * @param Request $request
     * @param Model   $unilevel_setting
     *
     * @return Response
     */
    public function edit(UnilevelSettingRequest $request, UnilevelSetting $unilevel_setting)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('unilevel_setting::unilevel_setting.name'))
            ->view('unilevel_setting::unilevel_setting.edit', true)
            ->data(compact('unilevel_setting'))
            ->output();
    }

    /**
     * Update the unilevel_setting.
     *
     * @param Request $request
     * @param Model   $unilevel_setting
     *
     * @return Response
     */
    public function update(UnilevelSettingRequest $request, UnilevelSetting $unilevel_setting)
    {
        try {
            $attributes = $request->all();

            $unilevel_setting->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('unilevel_setting::unilevel_setting.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('unilevel_setting/unilevel_setting/' . $unilevel_setting->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('unilevel_setting/unilevel_setting/' . $unilevel_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the unilevel_setting.
     *
     * @param Model   $unilevel_setting
     *
     * @return Response
     */
    public function destroy(UnilevelSettingRequest $request, UnilevelSetting $unilevel_setting)
    {
        try {

            $unilevel_setting->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('unilevel_setting::unilevel_setting.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('unilevel_setting/unilevel_setting/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('unilevel_setting/unilevel_setting/' . $unilevel_setting->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple unilevel_setting.
     *
     * @param Model   $unilevel_setting
     *
     * @return Response
     */
    public function delete(UnilevelSettingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('unilevel_setting::unilevel_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('unilevel_setting/unilevel_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/unilevel_setting/unilevel_setting'))
                ->redirect();
        }

    }

    /**
     * Restore deleted unilevel_settings.
     *
     * @param Model   $unilevel_setting
     *
     * @return Response
     */
    public function restore(UnilevelSettingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('unilevel_setting::unilevel_setting.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/unilevel_setting/unilevel_setting'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/unilevel_setting/unilevel_setting/'))
                ->redirect();
        }

    }

}
