<?php

namespace Litecms\UnilevelSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\UnilevelSetting\Models\UnilevelSetting;

class UnilevelSettingPolicy
{

    /**
     * Determine if the given user can view the unilevel_setting.
     *
     * @param UserPolicy $user
     * @param UnilevelSetting $unilevel_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, UnilevelSetting $unilevel_setting)
    {
        if ($user->canDo('unilevel_setting.unilevel_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $unilevel_setting->user_id == user_id() && $unilevel_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a unilevel_setting.
     *
     * @param UserPolicy $user
     * @param UnilevelSetting $unilevel_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('unilevel_setting.unilevel_setting.create');
    }

    /**
     * Determine if the given user can update the given unilevel_setting.
     *
     * @param UserPolicy $user
     * @param UnilevelSetting $unilevel_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, UnilevelSetting $unilevel_setting)
    {
        if ($user->canDo('unilevel_setting.unilevel_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $unilevel_setting->user_id == user_id() && $unilevel_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given unilevel_setting.
     *
     * @param UserPolicy $user
     * @param UnilevelSetting $unilevel_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, UnilevelSetting $unilevel_setting)
    {
        return $unilevel_setting->user_id == user_id() && $unilevel_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given unilevel_setting.
     *
     * @param UserPolicy $user
     * @param UnilevelSetting $unilevel_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, UnilevelSetting $unilevel_setting)
    {
        if ($user->canDo('unilevel_setting.unilevel_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given unilevel_setting.
     *
     * @param UserPolicy $user
     * @param UnilevelSetting $unilevel_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, UnilevelSetting $unilevel_setting)
    {
        if ($user->canDo('unilevel_setting.unilevel_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
